@@ -186,27 +186,18 @@ class Distribution(pd.Series):
 
         :return: NumPy array
         """
-        # TODO: Make this more efficient by implementing the inverse CDF method.
         pmf = self.make_pmf()
         return pmf.choice(*args, **kwargs)
 
     def sample(self, *args, **kwargs):
-        """Makes a random sample.
+        """Samples with replacement using probabilities as weights.
 
-        Uses the probabilities as weights unless `weights` is provided.
-
-        This function returns an array containing a sample of the
-        quantities in this Pmf, which is different from Series.sample,
-        which returns a Series with a sample of the rows in the original Series.
-
-        args: same as Series.sample
-        options: same as Series.sample
+        n: number of values
 
         :return: NumPy array
         """
-        # TODO: Make this more efficient by implementing the inverse CDF method.
-        pmf = self.make_pmf()
-        return pmf.sample(*args, **kwargs)
+        cdf = self.make_cdf()
+        return cdf.sample(*args, **kwargs)
 
     def add_dist(self, x):
         """Distribution of the sum of values drawn from self and x.
@@ -491,25 +482,6 @@ class Pmf(Distribution):
         underride(kwargs, p=self.ps)
         return np.random.choice(self.qs, *args, **kwargs)
 
-    def sample(self, *args, **kwargs):
-        """Makes a random sample.
-
-        Uses the probabilities as weights unless `weights` is provided.
-
-        This function returns an array containing a sample of the quantities in this Pmf,
-        which is different from Series.sample, which returns a Series with a sample of
-        the rows in the original Series.
-
-        args: same as Series.sample
-        options: same as Series.sample
-
-        :return: NumPy array
-        """
-        series = pd.Series(self.qs)
-        underride(kwargs, weights=self.ps)
-        sample = series.sample(*args, **kwargs)
-        return sample.values
-
     def add_dist(self, x):
         """Computes the Pmf of the sum of values drawn from self and x.
 
@@ -954,37 +926,15 @@ class Cdf(Distribution):
         """
         return dist.make_cdf()
 
-    def choice(self, *args, **kwargs):
-        """Makes a random sample.
+    def sample(self, n=1):
+        """Samples with replacement using probabilities as weights.
 
-        Uses the probabilities as weights unless `p` is provided.
-
-        args: same as np.random.choice
-        options: same as np.random.choice
+        n: number of values
 
         :return: NumPy array
         """
-        # TODO: Make this more efficient by implementing the inverse CDF method.
-        pmf = self.make_pmf()
-        return pmf.choice(*args, **kwargs)
-
-    def sample(self, *args, **kwargs):
-        """Makes a random sample.
-
-        Uses the probabilities as weights unless `weights` is provided.
-
-        This function returns an array containing a sample of the quantities in this Pmf,
-        which is different from Series.sample, which returns a Series with a sample of
-        the rows in the original Series.
-
-        args: same as Series.sample
-        options: same as Series.sample
-
-        :return: NumPy array
-        """
-        # TODO: Make this more efficient by implementing the inverse CDF method.
-        pmf = self.make_pmf()
-        return pmf.sample(*args, **kwargs)
+        ps = np.random.random(n)
+        return self.inverse(ps)
 
     def max_dist(self, n):
         """Distribution of the maximum of `n` values from this distribution.
